import traceback
from typing import Optional

from cpl_core.configuration.configuration_model_abc import ConfigurationModelABC
from cpl_core.console import Console


class ApplicationSettings(ConfigurationModelABC):

    def __init__(self):
        ConfigurationModelABC.__init__(self)

        self._name = ''
        self._repository = ''
        self._source_url = ''

    @property
    def name(self) -> str:
        return self._name
    
    @property
    def repository(self) -> str:
        return self._repository
    
    @property
    def source_url(self) -> Optional[str]:
        return self._source_url(self)

    def from_dict(self, settings: dict):
        try:
            self._name = settings['Name']
            self._repository = settings['Repository'] if 'Repository' in settings else None
            self._source_url = settings['SourceUrl'] if 'SourceUrl' in settings else None
        except Exception as e:
            Console.error(f'[ ERROR ] [ {__name__} ]: Reading error in {self.__name__} settings')
            Console.error(f'[ EXCEPTION ] [ {__name__} ]: {e} -> {traceback.format_exc()}')
